==> ark-21.04.2.tar.xz: ark-21.04.2/plugins/libsinglefileplugin/kerfuffle_libbz2.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the bzip2 algorithm",
        "Description[ast]": "Abre y estrái ficheros comprimíos individuales col algoritmu de bzip2",
        "Description[az]": "Bzip2 alqoritmi ilə sıxılmış tək faylları açmaq və çıxartmaq",
        "Description[ca@valencia]": "Obri i extreu fitxers individuals comprimits amb l'algorisme «bzip2»",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «bzip2»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem bzip2",
        "Description[da]": "Åbn og udpak enkelte filer komprimeret med bzip2-algoritmen",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem Bzip2-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο bzip2",
        "Description[en_GB]": "Open and extract single files compressed with the bzip2 algorithm",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo bzip2",
        "Description[et]": "Bzip2 algoritmiga pakitud failide avamine ja lahtipakkimine",
        "Description[eu]": "Ireki eta erauzi bzip2 algoritmoarekin konprimatutako fitxategiak banaka",
        "Description[fi]": "Avaa ja pura Bzip2-algoritmilla pakattuja yksittäistiedostoja",
        "Description[fr]": "Ouvre et extrait des fichiers compressés avec l'algorithme bzip2",
        "Description[gl]": "Abrir e extraer ficheiros individuais comprimidos co algoritmo bzip2.",
        "Description[hu]": "A bzip2 algoritmussal tömörített fájlok megnyitása és kibontása",
        "Description[ia]": "Aperir e extraher singule files comprimite con le algorithmo bzip2",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo bzip2",
        "Description[ko]": "bzip2 알고리즘으로 압축된 단일 파일 열고 풀기",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het bzip2-algoritme",
        "Description[nn]": "Opna og pakk ut einskildfiler komprimerte med bzip2-algoritmen",
        "Description[pl]": "Otwiera i wypakowuje pojedyncze pliki spakowane algorytmem bzip2",
        "Description[pt]": "Abrir e extrair ficheiros individuais comprimidos com o algoritmo Bzip2",
        "Description[pt_BR]": "Abrir e extrair arquivos individuais compactados com o algoritmo Bzip2",
        "Description[ro]": "Deschide și extrage fișiere singulare comprimate cu algoritmul bzip2",
        "Description[ru]": "Открытие и распаковка отдельных файлов, сжатых по алгоритму bzip2",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom bzip2",
        "Description[sl]": "Odprite in razširite datoteke stisnjene z algoritmom bzip2",
        "Description[sr@ijekavian]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом бзип2",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom bzip2",
        "Description[sr@latin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom bzip2",
        "Description[sr]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом бзип2",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med bzip2-algoritmen",
        "Description[tr]": "Bzip2 algoritması ile sıkıştırılmış tek dosyaları açma ve çıkarma",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму bzip2",
        "Description[x-test]": "xxOpen and extract single files compressed with the bzip2 algorithmxx",
        "Description[zh_CN]": "打开和解压 bzip2 算法压缩的单个文件",
        "Description[zh_TW]": "開啟並解壓縮以 bzip2 演算法壓縮的單一檔案",
        "Id": "kerfuffle_libbz2",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Bzip2 plugin",
        "Name[ast]": "Plugin pa bzip2",
        "Name[az]": "Bzip2 qoşması",
        "Name[ca@valencia]": "Connector del Bzip2",
        "Name[ca]": "Connector del Bzip2",
        "Name[cs]": "Modul pro bzip2",
        "Name[da]": "Bzip2-plugin",
        "Name[de]": "Bzip2-Modul",
        "Name[el]": "Πρόσθετο Bzip2",
        "Name[en_GB]": "Bzip2 plugin",
        "Name[es]": "Complemento Bzip2",
        "Name[et]": "Bzip2 plugin",
        "Name[eu]": "Bzip2 plugina",
        "Name[fi]": "Bzip2-liitännäinen",
        "Name[fr]": "Module externe « bzip2 »",
        "Name[gl]": "Complemento de bzip2",
        "Name[hu]": "Bzip2 bővítmény",
        "Name[ia]": "Plugin d Bzip2",
        "Name[it]": "Estensione Bzip2",
        "Name[ja]": "Bzip2 プラグイン",
        "Name[ko]": "Bzip2 플러그인",
        "Name[nl]": "Bzip2-plug-in",
        "Name[nn]": "Bzip2-tillegg",
        "Name[pl]": "Wtyczka bzip2",
        "Name[pt]": "'Plugin' do Bzip2",
        "Name[pt_BR]": "Plugin Bzip2",
        "Name[ro]": "Extensie Bzip2",
        "Name[ru]": "Модуль Bzip2",
        "Name[sk]": "Plugin Bzip2",
        "Name[sl]": "Vstavek Bzip2",
        "Name[sr@ijekavian]": "Прикључак за бзип2",
        "Name[sr@ijekavianlatin]": "Priključak za bzip2",
        "Name[sr@latin]": "Priključak za bzip2",
        "Name[sr]": "Прикључак за бзип2",
        "Name[sv]": "Bzip2-insticksprogram",
        "Name[tr]": "Bzip2 eklentisi",
        "Name[uk]": "Додаток bzip2",
        "Name[x-test]": "xxBzip2 pluginxx",
        "Name[zh_CN]": "Bzip2 插件",
        "Name[zh_TW]": "Bzip2 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Priority": 100
}

==> ark-22.03.80.tar.xz: ark-22.03.80/plugins/libsinglefileplugin/kerfuffle_libbz2.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the bzip2 algorithm",
        "Description[ar]": "يفتح و يستخرج الملفات المفردة المضغوطة باستخدام خوارزمية bzip2",
        "Description[ast]": "Abre y estrái ficheros comprimíos individuales col algoritmu de bzip2",
        "Description[az]": "Bzip2 alqoritmi ilə sıxılmış tək faylları açmaq və çıxartmaq",
        "Description[bg]": "Отваряне и извличане на единични файлове, компресирани с алгоритъм bzip2",
        "Description[ca@valencia]": "Obri i extreu fitxers individuals comprimits amb l'algorisme «bzip2»",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «bzip2»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem bzip2",
        "Description[da]": "Åbn og udpak enkelte filer komprimeret med bzip2-algoritmen",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem Bzip2-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο bzip2",
        "Description[en_GB]": "Open and extract single files compressed with the bzip2 algorithm",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo bzip2",
        "Description[et]": "Bzip2 algoritmiga pakitud failide avamine ja lahtipakkimine",
        "Description[eu]": "Ireki eta erauzi bzip2 algoritmoarekin konprimatutako fitxategi bakunak",
        "Description[fi]": "Avaa ja pura Bzip2-algoritmilla pakattuja yksittäistiedostoja",
        "Description[fr]": "Ouvre et extrait des fichiers compressés avec l'algorithme bzip2",
        "Description[gl]": "Abrir e extraer ficheiros individuais comprimidos co algoritmo bzip2.",
        "Description[hu]": "A bzip2 algoritmussal tömörített fájlok megnyitása és kibontása",
        "Description[ia]": "Aperir e extraher singule files comprimite con le algorithmo bzip2",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo bzip2",
        "Description[ko]": "bzip2 알고리즘으로 압축된 단일 파일 열고 풀기",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het bzip2-algoritme",
        "Description[nn]": "Opna og pakk ut einskildfiler komprimerte med bzip2-algoritmen",
        "Description[pl]": "Otwiera i wypakowuje pojedyncze pliki spakowane algorytmem bzip2",
        "Description[pt]": "Abrir e extrair ficheiros individuais comprimidos com o algoritmo Bzip2",
        "Description[pt_BR]": "Abrir e extrair arquivos individuais compactados com o algoritmo Bzip2",
        "Description[ro]": "Deschide și extrage fișiere singulare comprimate cu algoritmul bzip2",
        "Description[ru]": "Открытие и распаковка отдельных файлов, сжатых по алгоритму bzip2",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom bzip2",
        "Description[sl]": "Odprite in razširite datoteke stisnjene z algoritmom bzip2",
        "Description[sr@ijekavian]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом бзип2",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom bzip2",
        "Description[sr@latin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom bzip2",
        "Description[sr]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом бзип2",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med bzip2-algoritmen",
        "Description[tr]": "Bzip2 algoritması ile sıkıştırılmış tek dosyaları açın ve çıkarın",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму bzip2",
        "Description[x-test]": "xxOpen and extract single files compressed with the bzip2 algorithmxx",
        "Description[zh_CN]": "打开和解压 bzip2 算法压缩的单个文件",
        "Description[zh_TW]": "開啟並解壓縮以 bzip2 演算法壓縮的單一檔案",
        "Id": "kerfuffle_libbz2",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Bzip2 plugin",
        "Name[ar]": "ملحق Bzip2",
        "Name[ast]": "Plugin pa bzip2",
        "Name[az]": "Bzip2 qoşması",
        "Name[bg]": "Приставка Bzip2",
        "Name[ca@valencia]": "Connector del Bzip2",
        "Name[ca]": "Connector del Bzip2",
        "Name[cs]": "Modul pro bzip2",
        "Name[da]": "Bzip2-plugin",
        "Name[de]": "Bzip2-Modul",
        "Name[el]": "Πρόσθετο Bzip2",
        "Name[en_GB]": "Bzip2 plugin",
        "Name[es]": "Complemento Bzip2",
        "Name[et]": "Bzip2 plugin",
        "Name[eu]": "Bzip2 plugina",
        "Name[fi]": "Bzip2-liitännäinen",
        "Name[fr]": "Module externe « bzip2 »",
        "Name[gl]": "Complemento de bzip2",
        "Name[hu]": "Bzip2 bővítmény",
        "Name[ia]": "Plugin d Bzip2",
        "Name[it]": "Estensione Bzip2",
        "Name[ja]": "Bzip2 プラグイン",
        "Name[ko]": "Bzip2 플러그인",
        "Name[nl]": "Bzip2-plug-in",
        "Name[nn]": "Bzip2-tillegg",
        "Name[pl]": "Wtyczka bzip2",
        "Name[pt]": "'Plugin' do Bzip2",
        "Name[pt_BR]": "Plugin Bzip2",
        "Name[ro]": "Extensie Bzip2",
        "Name[ru]": "Модуль Bzip2",
        "Name[sk]": "Plugin Bzip2",
        "Name[sl]": "Vstavek Bzip2",
        "Name[sr@ijekavian]": "Прикључак за бзип2",
        "Name[sr@ijekavianlatin]": "Priključak za bzip2",
        "Name[sr@latin]": "Priključak za bzip2",
        "Name[sr]": "Прикључак за бзип2",
        "Name[sv]": "Bzip2-insticksprogram",
        "Name[tr]": "Bzip2 eklentisi",
        "Name[uk]": "Додаток bzip2",
        "Name[x-test]": "xxBzip2 pluginxx",
        "Name[zh_CN]": "Bzip2 插件",
        "Name[zh_TW]": "Bzip2 外掛程式",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Priority": 100
}
